![License](https://img.shields.io/github/license/kennychowdhary/tesuract)
![PyPI](https://img.shields.io/pypi/v/tesuract)


# tesuract

Python library for tensor surrogate approximation and prediction, compatible with sklearn's API. 

# Documentation

The sphinx documentation can be found [here](https://kennychowdhary.github.io/tesuract). The source can also be built by running `make html` in the `docs/` folder. 
